package
Version:
v0.0.0-...-90e558c
Opens a new window with list of versions in this module.
Published: Dec 29, 2021
License: MIT
Opens a new window with license information.
Imports: 1
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type TextEqualsFilterObject struct {
Property string `json:"property,omitempty"`
Text struct {
Equals string `json:"equals,omitempty"`
} `json:"text,omitempty"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.